==> ja-xdtp-1.1.4.tbz: share/xdtp/emacs/hanbun.el <==
;;;
;;; Hanbun mode version 0.11
;;;
;;l author: Daichi GOTO <daichi@freebsd.org>
;;; first edition: ? (I got forget :)
;;; last modified: Fri Jan  6 17:13:45 2006

;;; TODO
;;;    1. make as hanbun-mode (2005/11/02)
;;;    2. do implement completion function with tab key (2003/08/25)
;;;    


; --------------- hanbun-mode shortcut key ----------------
;
;; hanbun-mode shortcut key
(global-set-key "\C-ct" 'insert-hanbun-tag)

; ----------- locale-coding-system for hanbun -------------
;
;; hanbun-locale-coding-system
(defvar hanbun-locale-coding-system
  (cond
   ((string-equal "utf-8" locale-coding-system) "UTF-8")
   ((string-equal "japanese-iso-8bit" locale-coding-system) "EUC-JP")
   ((string-equal "japanese-shift-jis" locale-coding-system) "ShiftJIS")
   ((string-equal "iso-2022-jp" locale-coding-system) "ISO-2022-JP")
   ((string-equal nil locale-coding-system) "ISO-8859-1")
   (t (symbol-name locale-coding-system))
   )
  "Locale coding system for Hanbun mode")

; ------------------- completion table --------------------
;
;; hanbun tag name table
(defvar hanbun-module-tag-name-table
  '(("document") ("docgroup") ("docinfo") ("title") ("author") 
    ("firstedition") ("lastmodified") ("p") 
    )
  "Completion table for Hanbun module."
  )

;; hanbun text module tag name table
(defvar hanbun-text-module-tag-name-table
  '(("list") ("item") ("thebibliography") ("bibitem") ("author") 
    ("title") ("publisher") ("year") ("import") ("footnote")
    ("access") ("mark") ("ruby")
    )
  "Completion table for Hanbun text module."
  )

;; hanbun banbun module tag name table
(defvar hanbun-banbun-module-tag-name-table
  '(("number") ("category")
    )
  "Completion table for Hanbun banbun module."
  )

;; full hanbun tag name table composed of above
(defvar hanbun-tag-name-table
  (append
   hanbun-module-tag-name-table
   hanbun-text-module-tag-name-table
   hanbun-banbun-module-tag-name-table
   )
  "Completion table for Hanbun."
  )


; ----------------- completion function ------------------
;
;; completion insert
(defun insert-hanbun-tag ()
  (interactive)
  (let ((tag-name (completing-read "Tag: " hanbun-tag-name-table))
        )
    (cond
     ;; completion insert of import tag
     ((string-equal "import" tag-name)
      (insert-hanbun-text-module-import-tag)
      )
     
     ;; completion insert of access tag
     ((string-equal "access" tag-name)
      (insert-hanbun-text-module-access-tag)
      )
     
     ;; completion insert of list tag
     ((string-equal "list" tag-name)
      (insert-hanbun-text-module-list-tag)
      )
     
     ;; completion insert of document tag
     ((string-equal "document" tag-name)
      (insert-hanbun-document-tag)
      )

     ;; completion insert of docgroup tag
     ((string-equal "docgroup" tag-name)
      (insert-hanbun-docgroup-tag)
      )

     ;; completion insert of docinfo tag
     ((string-equal "docinfo" tag-name)
      (insert-hanbun-docinfo-tag)
      )

     ;; insert non-structure element tag
     (t
      (insert (message "<%s>" tag-name))
      (save-excursion
        (insert (message "</%s>" tag-name)))
      )
     )
    )
  )

;; completion insert of import tag
(defun insert-hanbun-text-module-import-tag ()
  (interactive)
  (let ((import-type 
         (completing-read "type: " 
                          hanbun-text-module-import-element-type-table))
        )
    (cond
     ;; 
     ((string-equal "text/csv" import-type)
      (insert "<import type=\"text/csv\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"csvs/\" caption=\"\" />")
      )
    
    ;; 
    ((string-equal "text/sourcecode" import-type)
      (insert "<import type=\"text/sourcecode\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"sources/\" caption=\"\" />")
      )

     ;; 
     ((string-equal "text/command-prompt" import-type)
      (insert "<import type=\"text/command-prompt\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"commands/\" caption=\"\" />")
      )

     ;; 
     ((string-equal "image/png" import-type)
      (insert "<import type=\"image/png\" id=\"\" ")
      (insert "ref=\"images/\" caption=\"\" />")
      )
     
     ;; 
     ((string-equal "image/jpeg" import-type)
      (insert "<import type=\"image/jpeg\" id=\"\" ")
      (insert "ref=\"images/\" caption=\"\" />")
      )

     ;; 
     ((string-equal "image/gif" import-type)
      (insert "<import type=\"image/gif\" id=\"\" ")
      (insert "ref=\"images/\" caption=\"\" />")
      )

     ;;
     (t
      (insert (message "<import type=\"%s\" id=\"\" ") import-type)
      (insert "ref=\"images/\" caption=\"\" />")
      )
     )
    )
  )

(defvar hanbun-text-module-import-element-type-table
  '(("text/csv") ("text/sourcecode") ("text/command-prompt") 
    ("image/png") ("image/jpeg") ("image/gif")
    )
  "import element type table."
  )

;; completion insert of access tag
(defun insert-hanbun-text-module-access-tag ()
  (interactive)
  (let ((import-type 
         (completing-read "type: " 
                          hanbun-text-module-access-element-type-table))
        )
    (cond
     ;; empty type
     ((string-equal "empty" import-type)
      (insert "<access ref=\"glsd:")
      (save-excursion
        (insert "\" />")
        )
      )

     ;; normal type
     (t
      (insert "<access ref=\"\">")
      (save-excursion
        (insert "</access>")
        )
      )    
     )
    )
  )

(defvar hanbun-text-module-access-element-type-table
  '(("empty") ("normal")
    )
  "access element type table."
  )

;; completion insert of list tag
(defun insert-hanbun-text-module-list-tag ()
  (interactive)
  (let ((import-type 
         (completing-read "type: " 
                          hanbun-text-module-access-element-type-table))
        (indent-length (current-column))
        )
    (cond
     ;; order type
     ((string-equal "order" import-type)
      (insert "<list type=\"order\">\n")
      )
     
     ;; itemize type
     (t
      (insert "<list>\n")
      )
     )
    
    (insert-char ?\  indent-length)
    (insert " <item><p>")
    (save-excursion
      (insert "</p></item>\n")
      (dotimes (count 4)
        (insert-char ?\  indent-length)
        (insert " <item><p></p></item>\n")
        )
      (insert-char ?\  indent-length)
      (insert "</list>")
      )
    )
  )

(defvar hanbun-text-module-list-element-type-table
  '(("itemize") ("order")
    )
  "list element type table."
  )

;; completion insert of docinfo tag
(defun insert-hanbun-docinfo-tag ()
  (interactive)
  (let ((indent-length (current-column))
        )
    (insert "<docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert " <title><p>")

    (save-excursion
      (insert "</p></title>\n")

      (insert-char ?\  indent-length)
      (insert "</docinfo>")
      )
    )
  )

;; completion insert of docgroup tag
(defun insert-hanbun-docgroup-tag ()
  (interactive)
  (let ((title (read-string "title: "))
        (indent-length (current-column))
        )
    (insert "<docgroup>\n")
    
    (insert-char ?\  indent-length)
    (insert " <docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert (message "  <title><p>%s</p></title>\n" title))

    (insert-char ?\  indent-length)
    (insert " </docinfo>\n\n")

    (insert-char ?\  indent-length)
    (insert " <p>")

    (save-excursion
      (insert "</p>\n\n")

      (dotimes (count 5)
        (insert-char ?\  indent-length)
        (insert " <p></p>\n\n")
        )
      
      (insert-char ?\  indent-length)
      (insert "</docgroup>")
      )
    )
  )

;; completion insert of document tag
(defun insert-hanbun-document-tag ()
  (interactive)
  (let ((title (read-string "title: "))
        (author (read-string "author: "))
        (indent-length (current-column))
        )
    (insert-char ?\  indent-length)
    (insert "<?xml version=\"1.0\" encoding=\"")
    (insert hanbun-locale-coding-system)
    (insert "\"?>\n\n")
    
    (insert-char ?\  indent-length)
    (insert "<document>\n")
    
    (insert-char ?\  indent-length)
    (insert " <docgroup>\n")
    
    (insert-char ?\  indent-length)
    (insert "  <docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert (message "   <title><p>%s</p></title>\n" title))
    
    (insert-char ?\  indent-length)
    (insert (message "   <author><p>%s</p></author>\n" author))
    
    (insert-char ?\  indent-length)
    (insert (message "   <firstedition><p>%s</p></firstedition>\n" 
                     (current-time-string)))
    
    (insert-char ?\  indent-length)
    (insert "   <lastmodified><p>$Date$ $Revision$</p></lastmodified>\n")
    
    (insert-char ?\  indent-length)
    (insert "  </docinfo>\n\n")
    
    (insert-char ?\  indent-length)
    (insert "  <docgroup>\n")
    
    (insert-char ?\  indent-length)
    (insert "   <docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert "    <title><p>")
    
    (save-excursion
      (insert-char ?\  indent-length)
      (insert "</p></title>\n")
      
      (insert-char ?\  indent-length)
      (insert "   </docinfo>\n\n")
      
      (dotimes (pcount 5)
        (insert-char ?\  indent-length)
        (insert "   <p></p>\n\n")
        )
      
      (insert-char ?\  indent-length)
      (insert "  </docgroup>\n\n")
      
      (dotimes (count 4)
        (insert-char ?\  indent-length)
        (insert "  <docgroup>\n")
        
        (insert-char ?\  indent-length)
        (insert "   <docinfo>\n")
        
        (insert-char ?\  indent-length)
        (insert "    <title><p></p></title>\n")
        
        (insert-char ?\  indent-length)
        (insert "   </docinfo>\n\n")
        
        (dotimes (pcount 5)
          (insert-char ?\  indent-length)
          (insert "   <p></p>\n\n")
          )
        
        (insert-char ?\  indent-length)
        (insert "  </docgroup>\n\n")
        )
      
      (insert-char ?\  indent-length)
      (insert " </docgroup>\n")
      
      (insert-char ?\  indent-length)
      (insert "</document>")
      )
    )
  )

==> ja-xdtp-1.2.0_1.tbz: share/xdtp/emacs/hanbun.el <==
;;;
;;; Hanbun mode version 0.12
;;;
;;l author: Daichi GOTO <daichi@freebsd.org>
;;; first edition: ? (I got forget :)
;;; last modified: Thu Jul 13 21:59:48 2006

;;; TODO
;;;    1. make as hanbun-mode (2005/11/02)
;;;    2. do implement completion function with tab key (2003/08/25)
;;;    


; --------------- hanbun-mode shortcut key ----------------
;
;; hanbun-mode shortcut key
(global-set-key "\C-ct" 'insert-hanbun-tag)

; ----------- locale-coding-system for hanbun -------------
;
;; hanbun-locale-coding-system
(defvar hanbun-locale-coding-system
  (cond
   ((string-equal "utf-8" locale-coding-system) "UTF-8")
   ((string-equal "japanese-iso-8bit" locale-coding-system) "EUC-JP")
   ((string-equal "japanese-shift-jis" locale-coding-system) "ShiftJIS")
   ((string-equal "iso-2022-jp" locale-coding-system) "ISO-2022-JP")
   ((string-equal nil locale-coding-system) "ISO-8859-1")
   (t (symbol-name locale-coding-system))
   )
  "Locale coding system for Hanbun mode")

; ------------------- completion table --------------------
;
;; hanbun tag name table
(defvar hanbun-module-tag-name-table
  '(("document") ("docgroup") ("docinfo") ("title") ("author") 
    ("firstedition") ("lastmodified") ("initialnumber") ("p") 
    )
  "Completion table for Hanbun module."
  )

;; hanbun text module tag name table
(defvar hanbun-text-module-tag-name-table
  '(("list") ("item") ("thebibliography") ("bibitem") ("author") 
    ("title") ("publisher") ("year") ("import") ("footnote")
    ("access") ("mark") ("ruby") ("alias")
    )
  "Completion table for Hanbun text module."
  )

;; hanbun banbun module tag name table
(defvar hanbun-banbun-module-tag-name-table
  '(("number") ("category") ("revisionnumber") ("newernumber") 
    ("obsoletenumber")
    )
  "Completion table for Hanbun banbun module."
  )

;; full hanbun tag name table composed of above
(defvar hanbun-tag-name-table
  (append
   hanbun-module-tag-name-table
   hanbun-text-module-tag-name-table
   hanbun-banbun-module-tag-name-table
   )
  "Completion table for Hanbun."
  )


; ----------------- completion function ------------------
;
;; completion insert
(defun insert-hanbun-tag ()
  (interactive)
  (let ((tag-name (completing-read "Tag: " hanbun-tag-name-table))
        )
    (cond
     ;; completion insert of import tag
     ((string-equal "import" tag-name)
      (insert-hanbun-text-module-import-tag)
      )
     
     ;; completion insert of access tag
     ((string-equal "access" tag-name)
      (insert-hanbun-text-module-access-tag)
      )
     
     ;; completion insert of list tag
     ((string-equal "list" tag-name)
      (insert-hanbun-text-module-list-tag)
      )
     
     ;; completion insert of document tag
     ((string-equal "document" tag-name)
      (insert-hanbun-document-tag)
      )

     ;; completion insert of docgroup tag
     ((string-equal "docgroup" tag-name)
      (insert-hanbun-docgroup-tag)
      )

     ;; completion insert of docinfo tag
     ((string-equal "docinfo" tag-name)
      (insert-hanbun-docinfo-tag)
      )

     ;; insert non-structure element tag
     (t
      (insert (message "<%s>" tag-name))
      (save-excursion
        (insert (message "</%s>" tag-name)))
      )
     )
    )
  )

;; completion insert of import tag
(defun insert-hanbun-text-module-import-tag ()
  (interactive)
  (let ((import-type 
         (completing-read "type: " 
                          hanbun-text-module-import-element-type-table))
        )
    (cond
     ;; 
     ((string-equal "text/csv" import-type)
      (insert "<import type=\"text/csv\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"csvs/\" caption=\"\" />")
      )
    
    ;; 
    ((string-equal "text/sourcecode" import-type)
      (insert "<import type=\"text/sourcecode\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"sources/\" caption=\"\" />")
      )

     ;; 
     ((string-equal "text/command-prompt" import-type)
      (insert "<import type=\"text/command-prompt\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"commands/\" caption=\"\" />")
      )

     ;; 
     ((string-equal "text/glsd-document" import-type)
      (insert "<import type=\"text/glsd-document\" encoding=\"")
      (insert hanbun-locale-coding-system)
      (insert "\" id=\"\" ref=\"\" caption=\"\" />")
      )

     ;; 
     ((string-equal "image/png" import-type)
      (insert "<import type=\"image/png\" id=\"\" ")
      (insert "ref=\"images/\" caption=\"\" />")
      )
     
     ;; 
     ((string-equal "image/jpeg" import-type)
      (insert "<import type=\"image/jpeg\" id=\"\" ")
      (insert "ref=\"images/\" caption=\"\" />")
      )

     ;; 
     ((string-equal "image/gif" import-type)
      (insert "<import type=\"image/gif\" id=\"\" ")
      (insert "ref=\"images/\" caption=\"\" />")
      )

     ;;
     (t
      (insert (message "<import type=\"%s\" id=\"\" ") import-type)
      (insert "ref=\"images/\" caption=\"\" />")
      )
     )
    )
  )

(defvar hanbun-text-module-import-element-type-table
  '(("text/csv") ("text/sourcecode") ("text/command-prompt") 
    ("text/glsd-document") ("image/png") ("image/jpeg") ("image/gif")
    )
  "import element type table."
  )

;; completion insert of access tag
(defun insert-hanbun-text-module-access-tag ()
  (interactive)
  (let ((import-type 
         (completing-read "type: " 
                          hanbun-text-module-access-element-type-table))
        )
    (cond
     ;; empty type
     ((string-equal "empty" import-type)
      (insert "<access ref=\"glsd:")
      (save-excursion
        (insert "\" />")
        )
      )

     ;; normal type
     (t
      (insert "<access ref=\"\">")
      (save-excursion
        (insert "</access>")
        )
      )
     )
    )
  )

(defvar hanbun-text-module-access-element-type-table
  '(("empty") ("normal")
    )
  "access element type table."
  )

;; completion insert of list tag
(defun insert-hanbun-text-module-list-tag ()
  (interactive)
  (let ((import-type 
         (completing-read "type: " 
                          hanbun-text-module-access-element-type-table))
        (indent-length (current-column))
        )
    (cond
     ;; order type
     ((string-equal "order" import-type)
      (insert "<list type=\"order\">\n")
      )
     
     ;; itemize type
     (t
      (insert "<list>\n")
      )
     )
    
    (insert-char ?\  indent-length)
    (insert " <item><p>")
    (save-excursion
      (insert "</p></item>\n")
      (dotimes (count 10)
        (insert-char ?\  indent-length)
        (insert " <item><p></p></item>\n")
        )
      (insert-char ?\  indent-length)
      (insert "</list>")
      )
    )
  )

(defvar hanbun-text-module-list-element-type-table
  '(("itemize") ("order")
    )
  "list element type table."
  )

;; completion insert of docinfo tag
(defun insert-hanbun-docinfo-tag ()
  (interactive)
  (let ((indent-length (current-column))
        )
    (insert "<docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert " <title><p>")

    (save-excursion
      (insert "</p></title>\n")

      (insert-char ?\  indent-length)
      (insert "</docinfo>")
      )
    )
  )

;; completion insert of docgroup tag
(defun insert-hanbun-docgroup-tag ()
  (interactive)
  (let ((title (read-string "title: "))
        (indent-length (current-column))
        )
    (insert "<docgroup>\n")
    
    (insert-char ?\  indent-length)
    (insert " <docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert (message "  <title><p>%s</p></title>\n" title))

    (insert-char ?\  indent-length)
    (insert " </docinfo>\n\n")

    (insert-char ?\  indent-length)
    (insert " <p>")

    (save-excursion
      (insert "</p>\n\n")

      (dotimes (count 5)
        (insert-char ?\  indent-length)
        (insert " <p></p>\n\n")
        )
      
      (insert-char ?\  indent-length)
      (insert "</docgroup>")
      )
    )
  )

;; completion insert of document tag
(defun insert-hanbun-document-tag ()
  (interactive)
  (let ((title (read-string "title: "))
        (author (read-string "author: "))
        (indent-length (current-column))
        )
    (insert-char ?\  indent-length)
    (insert "<?xml version=\"1.0\" encoding=\"")
    (insert hanbun-locale-coding-system)
    (insert "\"?>\n\n")
    
    (insert-char ?\  indent-length)
    (insert "<document>\n")
    
    (insert-char ?\  indent-length)
    (insert " <docgroup>\n")
    
    (insert-char ?\  indent-length)
    (insert "  <docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert (message "   <title><p>%s</p></title>\n" title))
    
    (insert-char ?\  indent-length)
    (insert (message "   <author><p>%s</p></author>\n" author))
    
    (insert-char ?\  indent-length)
    (insert (message "   <firstedition><p>%s</p></firstedition>\n" 
                     (current-time-string)))
    
    (insert-char ?\  indent-length)
    (insert "   <lastmodified><p>$Date$ $Revision$</p></lastmodified>\n")
    
    (insert-char ?\  indent-length)
    (insert "  </docinfo>\n\n")
    
    (insert-char ?\  indent-length)
    (insert "  <docgroup>\n")
    
    (insert-char ?\  indent-length)
    (insert "   <docinfo>\n")
    
    (insert-char ?\  indent-length)
    (insert "    <title><p>")
    
    (save-excursion
      (insert-char ?\  indent-length)
      (insert "</p></title>\n")
      
      (insert-char ?\  indent-length)
      (insert "   </docinfo>\n\n")
      
      (dotimes (pcount 5)
        (insert-char ?\  indent-length)
        (insert "   <p></p>\n\n")
        )
      
      (insert-char ?\  indent-length)
      (insert "  </docgroup>\n\n")
      
      (dotimes (count 4)
        (insert-char ?\  indent-length)
        (insert "  <docgroup>\n")
        
        (insert-char ?\  indent-length)
        (insert "   <docinfo>\n")
        
        (insert-char ?\  indent-length)
        (insert "    <title><p></p></title>\n")
        
        (insert-char ?\  indent-length)
        (insert "   </docinfo>\n\n")
        
        (dotimes (pcount 5)
          (insert-char ?\  indent-length)
          (insert "   <p></p>\n\n")
          )
        
        (insert-char ?\  indent-length)
        (insert "  </docgroup>\n\n")
        )
      
      (insert-char ?\  indent-length)
      (insert " </docgroup>\n")
      
      (insert-char ?\  indent-length)
      (insert "</document>")
      )
    )
  )
